@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: yesod-persistent
 version: 1.4.0.5
-id: yesod-persistent-1.4.0.5-629d475d7f77e3630b315100b50a92c4
-key: yesod_15jlxMZALfo9tWAZM5I50f
+id: yesod-persistent-1.4.0.5-bf9836848c5dd8bed1442734753db9ef
+key: yesod_GyKvPa6f9L4CX9FF2hapX2
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: Stable
@@ -20,17 +20,17 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-persistent-1.4.0.5
 library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-persistent-1.4.0.5
 data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-persistent-1.4.0.5
-hs-libraries: HSyesod-persistent-1.4.0.5-15jlxMZALfo9tWAZM5I50f
+hs-libraries: HSyesod-persistent-1.4.0.5-GyKvPa6f9L4CX9FF2hapX2
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     blaze-builder-0.4.0.2-290873936811c5be5456133d1e8642df
-    conduit-1.2.6.4-9cbf21b79aba616188d311eceb1fecef
-    persistent-2.2.4.1-b198a8037ee23ace95ee55f6faca82c3
-    persistent-template-2.1.6-4287f5b6884183e86ef158180d712d24
+    conduit-1.2.6.6-d359386885a03b60281b91c4e140d8f4
+    persistent-2.2.4.1-53b32e0b8931dd68fbb356ac374c65f3
+    persistent-template-2.1.6-0f50ab49755373ba8c00624f7c433aaf
     resource-pool-0.2.3.2-4273363c3eb17da3d6b84d801cb4d318
-    resourcet-1.1.7.3-7c6bcbec462b80120c27277d178fc6db
+    resourcet-1.1.7.4-51f149abafdcf0369a30d929df00de54
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
-    yesod-core-1.4.20.2-6a9eccc8751a316631c6c2141cb80eb5
+    yesod-core-1.4.20.2-b3dddaeebe1e00a8ca9ebbc062ef002b
 haddock-interfaces: /usr/share/doc/haskell-yesod-persistent/html/yesod-persistent.haddock
 haddock-html: /usr/share/doc/haskell-yesod-persistent/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
